<?php
/*
Plugin Name: Photopress Plugin
Plugin URI: http://familypress.net/photopress/
Description: Adds user-friendly image handling tools to Wordpress, including Upload and Browse buttons that insert image code into posts, a random image function, and a simple album.
Version: 0.7.1
Author: Isaac Wedin
Author URI: http://familypress.net/
*/

/* INSTALLATION
Extract the archive in your WP root folder, which puts photopress.php and the photopress folder in your plugins folder and creates a photos folder under wp-content. Make the photos folder writable, if necessary. Activate the plugin (or de-activate and re-activate if upgrading). Configure options at Options:Photopress. Photo information can be entered during upload or at Manage:Photopress Album.
*/

/*  Copyright 2004, 2005  Isaac Wedin (email : isaac@familypress.net)

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

/* include shared functions and defaults */
include_once('photopress/photopress-inc.php');

/* this function inserts javascript in the admin header to open the Upload and Browse popups */
function pp_popup_js() {
	echo '
	<script language="JavaScript" type="text/javascript"><!--
	/* it should be possible to do this with a single function that accepts an href, but that breaks the later stuff that calls these functions... */
	function pp_upload_popup() {
		var mylink = "' . get_settings('siteurl') . '/wp-content/plugins/photopress/upload.php";
		var windowname = "upload";
		if (! window.focus) return true;
			var href;
		if (typeof(mylink) == "string")
			href = mylink;
		else
			href = mylink.href;
		window.open(href, windowname, "width=400,height=600,scrollbars=yes");
		return false;
	}

	function pp_browse_popup() {
		var mylink = "' . get_settings('siteurl') . '/wp-content/plugins/photopress/browse.php";
		var windowname = "browse";
		if (! window.focus) return true;
			var href;
		if (typeof(mylink) == "string")
			href = mylink;
		else
			href = mylink.href;
			window.open(href, windowname, "width=400,height=600,scrollbars=yes");
			return false;
		}
	//--></script>
	';
}

add_action('admin_head','pp_popup_js');

/* This function adds the Upload and Browse buttons to the quicktags menu. Borrowed from ContactForm, which I think borrowed from Alex King's JS Quicktags.*/
function pp_insert_buttons() {
	echo '
	<script language="JavaScript" type="text/javascript">
	<!--
	document.getElementById("quicktags").innerHTML += "<input type=\"button\" class=\"ed_button\" id=\"ed_upload\" value=\"Browse\" onclick=\"return pp_browse_popup();\" /><input type=\"button\" class=\"ed_button\" id=\"ed_upload\" value=\"Upload\" onclick=\"return pp_upload_popup();\" />";
	//-->
	</script>
	';
}

add_action('admin_footer', 'pp_insert_buttons');

/* random image function, wants an array and a type it returns a random linked thumb by default set $type to 2 to get a bare tagged thumb, 3 for just the image name */
function pp_random_image($image_array, $type = 1) {
	global $pp_options, $pp_imagelink, $pp_photosaddress, $pp_photospath, $pp_target;
	if (count($image_array) > 1) {
		sort($image_array);
	}
	$image_count = sizeof($image_array);
	if ($image_count > 0) {
		if ($image_count > 1) {
			$r = rand(0,($image_count-1));
			$random_image = $image_array[$r];
		} else {
			$random_image = $image_array[0];
		}
		$random_image_thumb = $pp_options['pp_thumbprefix'].$random_image;
		$random_image_thumb_size = getimagesize("$pp_photospath/$random_image_thumb");
		if (pp_get_data($random_image)) {
			$random_data = pp_get_data($random_image);
			$random_alt_text = $random_data['imgdesc'];
		} else {
			$random_alt_text = str_replace("_", " ", substr($random_image, 0, -4));
		}
		$random_thumb = '<img class="centered" src="' . $pp_photosaddress . '/' . $random_image_thumb . '" ' . $random_image_thumb_size[3] . ' alt="' . $random_alt_text . '" />';
		$random_linked_thumb =  '<a href="' . htmlentities2($pp_imagelink) . $random_image . '" title="' . $random_alt_text . '" target="' . $pp_target . '">' . $random_thumb . '</a>';
	}
	if ($type == 3) {
		return $random_image;
	} elseif ($type == 2) {
		return $random_thumb;
	} else {
		return $random_linked_thumb;
	}
}

function pp_random_image_bare() {
	$pp_all_images = array();
	if (pp_folder_contents()) {
		$pp_all_images = pp_folder_contents();
		echo pp_random_image((array)$pp_all_images);
	} else {
		echo 'No images yet.';
	}
}

/* put a random link to the photo album and/or a random thumbnail in the meta section of the sidebar, depending on the options, does nothing if there aren't any images yet  */
function pp_stuff_in_meta() {
	global $pp_options, $pp_albumaddress;
	if (get_option('pp_options')) {
		$pp_options = get_option('pp_options');
	}
	if (pp_folder_contents()) {
		$image_array = array();
		$image_array = pp_folder_contents();
		$stuff_for_meta = '';
		if ($pp_options['pp_meta_link'] == 1) {
			$stuff_for_meta .= '<li><a href="' . $pp_albumaddress . '">Photo Album</a></li>' . "\n";
		}
		if ($pp_options['pp_meta_rand'] == 1) {
			$stuff_for_meta .= '<li>' . pp_random_image($image_array) . "</li>\n";
		}
		echo $stuff_for_meta;
	}
}

add_action('wp_meta', 'pp_stuff_in_meta');

/* wrapper function to display the album */
function pp_album() {
	global $pp_albumaddress;
	echo '<h2><a href="' . $pp_albumaddress . '">Photo Album</a></h2>';
	if (isset($_GET['pp_image'])) {
		$image = stripslashes($_GET['pp_image']);
		pp_display_image($image);
	} elseif (isset($_GET['pp_cat'])) {
		$cat = stripslashes($_GET['pp_cat']);
		pp_display_cat($cat);
	} else {
		pp_display_main();
	}
}

/* displays images from $category in an html table */
function pp_display_cat($category, $pp_embed = 0) {
	global $pp_albumaddress, $pp_photosaddress, $pp_albumpostfix, $pp_thumbprefix, $pp_album_columns, $pp_albumpostfix, $pp_allowedtypes, $pp_imagelink, $pp_photospath;
	if ($pp_embed == 0 ) {
		echo '<h3>' . stripslashes($category) . '</h3>';
	}
	$column = 0;
	$cat_images = array();
	$cat_images = pp_cat_images($category);
	echo '<table id="pp_gallery">
	';
	foreach($cat_images as $array_img) {
		$column++;
		if($column == 1) {
			echo '<tr>';
		}
		$thumbsize = getimagesize("$pp_photospath/$pp_thumbprefix$array_img");
		if (pp_get_data($array_img)) {
			$img_data = array();
			$img_data = pp_get_data($array_img);
			$cleanedname = $img_data[imgname];
		} else {
			$cleanedname = strtr(substr($array_img, 0, strrpos($array_img, '.')), "_", " ");
		}
		echo '<td class="pp_cell"><a href="' . htmlentities2($pp_imagelink) . $array_img . '" title="' . $cleanedname . '"><img src="' . $pp_photosaddress . '/' . $pp_thumbprefix . $array_img . '" ' . $thumbsize[3] . ' class="pp_centered" alt="' . $cleanedname . '" /><br />' . $cleanedname . '</a></td>';
		if($column == $pp_album_columns) {
			echo '</tr>
			';
			$column = 0;
		}
	}
	if ($column < $pp_album_columns && $column > 0) {
		echo '</tr>
		';
	}
	echo '</table>
	';
}

/* returns an image's category, defaults to 'Default' if none */
function pp_image_cat($image) {
	$category_array = array();
	if (get_option('pp_album_cats')) {
		$category_array = get_option('pp_album_cats');
		$category_array = array_filter($category_array, 'pp_not_empty');
	}
	$category = 'Default';
	foreach($category_array as $img => $cat) {
		if($image == substr_replace($img, '.', -4, 1)) {
			$category = $cat;
		}
	}
	return $category;
}

function pp_display_main() {
	global $pp_albumaddress, $pp_catpostfix, $pp_album_columns;
	$categories = array();
	$categories = pp_list_cats();
	$column = 0;
	echo '<table id="pp_gallery">
	';
	if (count($categories) > 1) {
		foreach($categories as $cat) {
			$column++;
			if ($column == 1) {
				echo '<tr>';
			}
			$cat_images = pp_cat_images($cat);
			$image_count = count($cat_images);
			echo '<td class="pp_cell"><a href="' . htmlentities2($pp_albumaddress) . htmlentities2($pp_catpostfix) . stripslashes($cat) . '" title="' . stripslashes($cat) . '">' . pp_random_image((array)$cat_images,2) . '<br />' . stripslashes($cat) . ' (' . $image_count . ')</a></td>';
			if ($column == $pp_album_columns) {
				echo '</tr>
				';
				$column = 0;
			}
		}
		if ($column < $pp_album_columns && $column > 0) {
			echo '</tr>
			';
		}
	} elseif (count($categories) == 1) {
		echo '<tr>';
		$cat_images = pp_cat_images($categories[0]);
		$image_count = count($cat_images);
		echo '<td class="pp_cell"><a href="' . htmlentities2($pp_albumaddress) . $pp_catpostfix . $categories[0] . '" title="' . stripslashes($categories[0]) . '">' . pp_random_image((array)$cat_images,2) . '<br />' . stripslashes($categories[0]) . ' (' . $image_count . ')</a></td>';
		echo '</tr>
		';
	} else {
		echo '<tr><td><strong>No photos uploaded yet</strong></td></tr>
		';
	}
	echo '</table>
	';
}

function pp_not_empty($string) {
	if ($string == 'Default') {
		return FALSE;
	} else {
		return !empty($string);
	}
}
	
function pp_allowed($image) {
	global $pp_allowedtypes;
	$allowedtypes = trim(strtolower($pp_allowedtypes));
	$allowedtypes = preg_replace("/ /","|",$allowedtypes);
	$image = strtolower($image);
	$fileglob = '@\_(' . $allowedtypes . ')$@i';
	return(preg_match($fileglob, $image));
}

/* displays an image, linked to a larger version) */
function pp_display_image($image) {
	global $pp_albumaddress, $pp_photosaddress, $pp_albumpostfix, $pp_catpostfix, $pp_photospath, $pp_show_posts, $pp_origprefix;
	if (file_exists("$pp_photospath/$image")) {
		if (pp_get_data($image)) {
			$image_data = pp_get_data($image);
			$image_cat = $image_data['imgcat'];
			$cleanedname = $image_data['imgname'];
			$imgdesc = $image_data['imgdesc'];
		} else {
			$image_cat = 'Default';
			$cleanedname = strtr(substr($image, 0, -4), "_", " ");
		}
		echo '<div id="pp_meta"><strong><a href="' . htmlentities2($pp_albumaddress) . htmlentities2($pp_catpostfix) . stripslashes($image_cat) . '">' . stripslashes($image_cat) . '</a> : ' . $cleanedname . '</strong></div>' . "\n";
		$cat_array = pp_cat_images($image_cat);
		$image_size = getimagesize("$pp_photospath/$image");
		if (count($cat_array) > 1 ) {
			sort($cat_array);
		}
		$itemcount = sizeof($cat_array);
		if ($itemcount > 1) {
			$prevnext = '<div id="pp_prevnext">' . "\n";
			for ($j = 0; $j < $itemcount; $j++) {
				$item = $cat_array[$j];
				if ($image == $item) {
					if ($cat_array[$j-1]) {
						$prevnext .= '<a class="pp_prev" href="' . htmlentities2($pp_albumaddress) . htmlentities2($pp_albumpostfix) . $cat_array[$j-1] . '">Previous</a>' . "\n";
					} else {
						$prevnext .= '<div class="pp_prev"></div>' . "\n";
					}
					if ($cat_array[$j+1]) {
						$prevnext .= '<a class="pp_next" href="' . htmlentities2($pp_albumaddress) . htmlentities2($pp_albumpostfix) . $cat_array[$j+1] . '">Next</a>' . "\n";
					} else {
						$prevnext .= '<div class="pp_next"></div>' . "\n";
					}
				}
			}
			$prevnext .= "</div>\n";
			echo $prevnext;
		}
		echo '<div id="pp_gallery">';
		if (is_file($pp_photospath. '/' . $pp_origprefix . $image)) {
			echo '<a href="' . htmlentities2($pp_photosaddress) . '/' . $pp_origprefix . $image . '" title="' . $cleanedname . '" target="_blank"><img class="pp_centered" src="' . $pp_photosaddress . '/' . $image . '" ' . $image_size[3] . ' alt="' . $cleanedname . '" /></a>';
		} else {
			echo '<a href="' . htmlentities2($pp_photosaddress) . '/' . $image . '" title="' . $cleanedname . '" target="_blank"><img class="pp_centered" src="' . $pp_photosaddress . '/' . $image . '" ' . $image_size[3] . ' alt="' . $cleanedname . '" /></a>';
		}
		if (!empty($imgdesc)) {
			echo '<p>' . $imgdesc . '</p>';
		}
		if ( $pp_show_posts == '1' ) {
			query_posts("s=$image");
			if ( have_posts() ) :
				echo '<p><strong>Posts with this image:</strong></p>
			<ul>';
			while ( have_posts() ) : the_post();
				echo '<li><a href="';
				the_permalink();
				echo '">';
				the_title();
				echo '</a></li>';
			endwhile;
			echo '</ul>';
		else: endif;
		}
		echo "</div>\n";
	} else {
		echo "<p>Image not found, probably deleted.</p>\n";
	}
}

function pp_album_template() {
	if ($_GET['pp_album']) {
		if ( file_exists(TEMPLATEPATH.'pp_album.php') ) {
			include(TEMPLATEPATH.'pp_album.php');
		} else {
			include('wp-content/plugins/photopress/album.php');
			exit;
		}
	}
	return;
}

add_action('template_redirect','pp_album_template');

function pp_album_css() {
	if ($_GET['pp_album']) {
		if (file_exists(TEMPLATEPATH . 'pp_album_css.php')) {
			include(TEMPLATEPATH . 'pp_album_css.php');
		} elseif (file_exists('wp-content/plugins/photopress/pp_album_css.php')) {
			include('wp-content/plugins/photopress/pp_album_css.php');
		}
	}
}

add_action('wp_head','pp_album_css');

/* the 8 here is the min level to edit the Photopress Options */
/* i guess it could be a variable that an admin could set?    */
function pp_add_options_page() {
	add_options_page('Photopress', 'Photopress', 8, __FILE__, 'pp_options_subpanel');
}

function pp_options_subpanel() {
	global $pp_options;

	if (isset($_POST['pp_options_update'])) {
		$pp_options = get_option('pp_options');
		echo '<div class="updated">Photopress options updated.</div>';
	}
	echo '
	<div class="wrap">
	<h2>Photopress Options</h2>
	<form name="pp_options" method="post">
	<input type="hidden" name="pp_options_update" value="update" />
	<fieldset class="options">
	<table width="100%" cellspacing="2" cellpadding="5" class="editform">
        <tr>
        <th scope="row">Retain original imagess:</th>
        <td>
        <label><input name="pp_originals" type="radio" value="1" ';
        if ($pp_options['pp_originals'] == '1') {echo 'checked="checked" ';}
        echo '/> Yes</label><br />
        <label><input name="pp_originals" type="radio" value="0" ';
        if ($pp_options['pp_originals'] == '0') {echo 'checked="checked" ';}
        echo ' /> No</label><br />
        </td>
        </tr>
	<tr>
	<th scope="row">Maximum size: </th>
	<td><input name="pp_maxk" type="text" id="pp_maxk" value="' . $pp_options['pp_maxk'] . '" size="4" /> 
	Kilobytes (KB)</td>
	</tr>
        <tr>
        <th scope="row">Maximum resized image size (width or height): </th>
        <td><input name="pp_maxsize" type="text" id="pp_maxsize" value="' . $pp_options['pp_maxsize'] . '" size="4" />
        pixels</td>
        </tr>
        <tr>
        <th scope="row">Maximum thumbnail size: </th>
        <td><input name="pp_thumbsize" type="text" id="pp_thumbsize" value="' . $pp_options['pp_thumbsize'] . '" size="4" />
        pixels</td>
        </tr>
        <tr>
        <th scope="row">Quality for resized JPEGs: </th>
        <td><input name="pp_quality" type="text" id="pp_quality" value="' . $pp_options['pp_quality'] . '" size="3" /><br />
        Recommended: between 70 and 95</td>
        </tr>
        <tr>
        <th scope="row">Photos folder: </th>
        <td><input name="pp_photofolder" type="text" id="pp_photofolder" value="' . $pp_options['pp_photofolder'] . '" size="10" /><br />
        Folder in wp-content to place images in, should be writable.</td>
        </tr>
        <tr>
        <th scope="row">Thumb prefix: </th>
        <td><input name="pp_thumbprefix" type="text" id="pp_thumbprefix" value="' . $pp_options['pp_thumbprefix'] . '" size="10" /><br />
        String to add to created thumbnails.</td>
        </tr>
        <tr>
        <th scope="row">Originals prefix: </th>
        <td><input name="pp_origprefix" type="text" id="pp_origprefix" value="' . $pp_options['pp_origprefix'] . '" size="10" /><br />
        String to add to the original image, if retained.</td>
        </tr>
	<tr>
	<th scope = "row">Album name: </th>
        <td><input name="pp_albumname" type="text" id="pp_albumname" value="' . $pp_options['pp_albumname'] . '" size="10" /><br />
	Default should be "?pp_album=1" - use something like "album" for permalinks.</td>
	</tr>
	<th scope = "row">Album postfix: </th>
        <td><input name="pp_albumpostfix" type="text" id="pp_albumpostfix" value="' . $pp_options['pp_albumpostfix'] . '" size="10" /><br />
	Default should be "&pp_image=" - use something like "/" for permalinks.</td>
	</tr>
	<tr>
	<th scope = "row">Category postfix: </th>
        <td><input name="pp_catpostfix" type="text" id="pp_catpostfix" value="' . $pp_options['pp_catpostfix'] . '" size="10" /><br />
	Default should be "&pp_cat=" - use something like "/category/" for permalinks.</td>
	</tr>
	<tr>
	<th scope="row">Insert Thumbs:</th>
	<td>
	<label><input name="pp_insert_thumb" type="radio" value="1" ';
	if ($pp_options['pp_insert_thumb'] == '1') {echo 'checked="checked" ';}
	echo '/> Yes</label><br />
	<label><input name="pp_insert_thumb" type="radio" value="0" ';
	if ($pp_options['pp_insert_thumb'] == '0') {echo 'checked="checked" ';}
	echo ' /> No</label>
	</td>
	</tr>
        <tr>
        <th scope="row">Link to Album:</th>
        <td>
	<label><input name="pp_album" type="radio" value="1" ';
	if ($pp_options['pp_album'] == '1') {echo 'checked="checked" ';}
	echo '/> Yes</label><br />
	<label><input name="pp_album" type="radio" value="0" ';
	if ($pp_options['pp_album'] == '0') {echo 'checked="checked" ';}
	echo '/> No</label><br />
        </td>
        </tr>
        <tr>
        <th scope="row">Insert Link in Meta:</th>
	<td>
	<label><input name="pp_meta_link" type="radio" value="1" ';
	if ($pp_options['pp_meta_link'] == '1') {echo 'checked="checked" ';}
	echo '/> Yes</label><br />
	<label><input name="pp_meta_link" type="radio" value="0" ';
	if ($pp_options['pp_meta_link'] == '0') {echo 'checked="checked" ';}
	echo '/> No</label><br />
        </td>
        </tr>
        <tr>
        <th scope="row">Insert Random Image in Meta:</th>
	<td>
	<label><input name="pp_meta_rand" type="radio" value="1" ';
	if ($pp_options['pp_meta_rand'] == '1') {echo 'checked="checked" ';}
	echo '/> Yes</label><br />
	<label><input name="pp_meta_rand" type="radio" value="0" ';
	if ($pp_options['pp_meta_rand'] == '0') {echo 'checked="checked" ';}
	echo '/> No</label><br />
        </td>
        </tr>
        <tr>
	<th scope="row">Add Failsafe Buttons:</th>
	<td>
	<label><input name="pp_failsafe_buttons" type="radio" value="1" ';
	if ($pp_options['pp_failsafe_buttons'] == '1') {echo 'checked="checked" ';}
	echo '/> Yes</label><br />
	<label><input name="pp_failsafe_buttons" type="radio" value="0" ';
	if ($pp_options['pp_failsafe_buttons'] == '0') {echo 'checked="checked" ';}
	echo '/> No</label><br />
	</td>
	</tr>
        <tr>
        <th scope="row">Show posts with image in album:</th>
        <td>
        <label><input name="pp_show_posts" type="radio" value="1" ';
        if ($pp_options['pp_show_posts'] == '1') {echo 'checked="checked" ';}         echo '/> Yes</label><br />
        <label><input name="pp_show_posts" type="radio" value="0" ';
        if ($pp_options['pp_show_posts'] == '0') {echo 'checked="checked" ';}
        echo '/> No</label><br />
        </td>
	</tr>
        <tr>
        <th scope="row">Show thumbs in the album manager:</th>
        <td>
        <label><input name="pp_thumbs_in_manager" type="radio" value="1" ';
        if ($pp_options['pp_thumbs_in_manager'] == '1') {echo 'checked="checked" ';}       echo '/> Yes</label><br />
        <label><input name="pp_thumbs_in_manager" type="radio" value="0" ';
        if ($pp_options['pp_thumbs_in_manager'] == '0') {echo 'checked="checked" ';}
        echo '/> No</label><br />
        </td>
        </tr>
        <tr>
        <th scope="row">Album columns: </th>
        <td><input name="pp_album_columns" type="text" id="pp_album_columns" value="' . $pp_options['pp_album_columns'] . '" size="3" /><br />
	Probably 2 if you have a sidebar, maybe 3 otherwise.
	</td>
        </tr>
	<tr>
	<th valign="top" scope="row">Allowed file extensions:</th>
	<td><input name="pp_allowedtypes" type="text" id="pp_allowedtypes" value="' . $pp_options['pp_allowedtypes'] . '" size="40" />
	<br />
	Recommended: <code>jpg png gif</code> (because that\'s all that\'ll get resized anyway)
	</td>
	</tr>
        <tr>
        <th scope="row">Class for inserted image style: </th>
        <td><input name="pp_align" type="text" id="pp_align" value="' . $pp_options['pp_align'] . '" size="10" /><br />
        (alignleft, alignright, and centered are available in the default theme - add a new class to your theme and enter the name here for custom style)
	</td>
        </tr>
	<tr>
	<th scope="row">Minimum level to upload and browse:</th>
	<td><select name="pp_min_level" id="pp_min_level">';
	for ($i = 1; $i <= 10; $i++) {
		echo '
		<option value="' . $i . '"';
		if ($pp_options['pp_min_level'] == $i) { echo ' selected="selected"'; }
		echo '>' . $i . '</option>';
	}
	echo '
	</select>
	</td>
	</tr>
	</table> 
	</fieldset>

	<p class="submit">
		<input type="submit" name="Submit" value="Update Options &raquo;" />
	</p>
</form> 
</div>
';
}

add_action('admin_menu', 'pp_add_options_page');

if (isset($_POST['pp_options_update'])) {
	$pp_updated_options = array();
	$pp_updated_options = $_POST;
	add_option('pp_options');
	update_option('pp_options', $pp_updated_options);
}

/* makes the Manage:Photopress Album pages */
function pp_album_management() {
	global $pp_imagelink, $pp_thumbprefix, $pp_photosaddress, $pp_target, $pp_deleted, $pp_not_deleted, $pp_options, $pp_photospath, $pp_album_updated;
	if ($pp_album_updated == '1') {
		echo '<div class="updated">Photopress album data updated.</div>';
	}
	if ($pp_deleted == '1') {
		echo '<div class="updated">' . $_GET['pp_delete'] . ' deleted.</div>';
	}
	if ($pp_not_deleted == '1') {
		echo '<div class="updated">' . $_GET['pp_delete'] . ' was not deleted for some reason.</div>';
	}
	echo '
	<div class="wrap">
	<h2>Photopress Album Management</h2>
	';
	if (pp_folder_contents()) {
		echo '<p><strong>Categories:</strong> ';
		$pp_categories = pp_list_cats();
		foreach ($pp_categories as $pp_cat) {
			$pp_cat_images = pp_cat_images($pp_cat);
			echo "\n<a href=\"edit.php?page=photopress.php&amp;pp_manage_cat=" . $pp_cat . "\">" . stripslashes($pp_cat) . " (" . count($pp_cat_images) . ")</a> ";
		}
		echo '
		</p>';
	} else {
	echo '<p>No images yet.</p>
	';
	}
	echo '<p><a href="#" onclick="return pp_upload_popup();">Click to upload some images</a>.</p>
	';
	if (isset($_GET['pp_manage_image'])) {
		$pp_manage_image = $_GET['pp_manage_image'];
		$pp_image_data = pp_get_data($pp_manage_image);
		echo '
		<form name="pp_album_cats" method="post">
		<input type="hidden" name="pp_album_update" value="update" />
		<input type="hidden" name="imgfile" value="' . $pp_image_data['imgfile'] . '" />
		<fieldset class="options">
		<table width="100%" cellspacing="2" cellpadding="5" class="editform">
		<tr><th scope="row">
		<img src="' . $pp_photosaddress . '/' . $pp_manage_image . '" alt="' . $pp_image_data['imgname'] . '" title="' . $pp_image_data['imgname'] . '" />
		</th><th scope="row"><td>
		Name: <input type="text" name="imgname" value="' . $pp_image_data['imgname'] . '" /><br />
		Description: <textarea rows="2" cols ="30" name="imgdesc" id="imgdesc" class="uploadform" value="' . $pp_image_data['imgdesc'] . '"></textarea><br />
		Category: <select name="oldimgcat" id="pp_oldimgcat">';
		/* add Default category if it isn't there */
		if (!in_array('Default', $pp_categories)) {
			$pp_categories[] = 'Default';
		}
		/* set image's category as Default if it's empty */
		if (empty($pp_image_data['imgcat'])) {
			$pp_image_data['imgcat'] = 'Default';
		}
		foreach ($pp_categories as $category) {
			echo '
			<option value="' . $category . '"';
			if ($pp_image_data['imgcat'] == $category) { echo ' selected="selected"'; }
				echo '>' . $category . '</option>';
			}
		echo '
		</select>
		 or enter new: <input type="text" name="newimgcat" value="" /><br />
		<p class="submit">
		<input type="submit" name="Submit" value="Update &raquo;" />
		</p>';
		query_posts("s=$pp_manage_image");
		if ( have_posts() ) :
		echo '<p>Posts with image:<br />';
		while ( have_posts() ) : the_post();
		echo ' <a href="';
		the_permalink();
		echo '">';
		the_title();
		echo '</a> ';
		endwhile;
		echo '</p>';
		else:
		echo "<p><a href=\"edit.php?page=photopress.php&amp;pp_manage_cat=" . stripslashes($pp_image_data['imgcat']) . "&pp_delete=" . $pp_manage_image . "\" class=\"delete\" onclick=\"return confirm('OK to delete " . $pp_manage_image . "?')\">" . $pp_manage_image . " isn't used in any posts. Delete?</a></p>\n";
		endif;
		echo '
		</td></tr></table>
		</fieldset>
		</form>';
	} elseif (isset($_GET['pp_manage_cat'])) {
		$pp_manage_cat = stripslashes($_GET['pp_manage_cat']);
		$pp_cat_images = pp_cat_images($pp_manage_cat);
		echo '
		<fieldset class="options">
		<table width="100%" cellspacing="2" cellpadding="5" class="editform">
		<tr><th scope="row">Images in <em>' . $pp_manage_cat . '</em> category:</th></tr>
		<tr><td>';
		sort($pp_cat_images);
		foreach($pp_cat_images as $pp_image) {
			$image_data = pp_get_data($pp_image);
			echo '<a href="edit.php?page=photopress.php&amp;pp_manage_image=' . $pp_image . '" title="' . $image_data['imgname'] . '">';
			if ($pp_options['pp_thumbs_in_manager'] == '1') {
				echo '<img src="' . $pp_photosaddress . '/' . $pp_thumbprefix . $pp_image . '" title="' . $image_data['imgname'] . '" alt="' . $image_data['imgname'] . '" /> ';
			} else {
				echo $pp_image . '<br />';
			}
			echo '</a>';
		}
	echo '
	</td></tr></table>
	</fieldset>';
	}
	echo '
	</div>';

}

function pp_add_management_page() {
	global $pp_min_level;
	add_management_page('Photopress Album', 'Photopress Album', $pp_min_level, __FILE__, 'pp_album_management');
}

add_action('admin_menu', 'pp_add_management_page');

if (isset($_POST['pp_album_update'])) {
	/* if they've manually entered a category name use that */
	if(!empty($_POST['newimgcat'])) {
		$pp_updated_cat = $_POST['newimgcat'];
	/* otherwise, use whatever the menu was set on */
	} else {
		$pp_updated_cat = $_POST['oldimgcat'];
	}
	$pp_updated = array($_POST['imgfile'],$_POST['imgname'],$_POST['imgdesc'],$pp_updated_cat);
	pp_table_update($pp_updated);
	$pp_album_updated = '1';
}

if (isset($_GET['pp_delete'])) {
	pp_delete_photo($_GET['pp_delete']);
}

/* delete function, not sure how secure it is... */
function pp_delete_photo($photo) {
	global $pp_photospath, $pp_thumbprefix, $wpdb, $table_prefix, $pp_min_level;
	$pp_phototodelete = $pp_photospath . '/' . $photo;
	$pp_thumbtodelete = $pp_photospath . '/' . $pp_thumbprefix . $photo;
	$table_name = $table_prefix . "photopress";
	if (!getimagesize($pp_thumbtodelete)) {
		$pp_not_deleted = '1';
	} else {
		@unlink($pp_phototodelete);
		@unlink($pp_thumbtodelete);
		$pp_deleted = '1';
		$pp_delete_data = $wpdb->query("DELETE FROM $table_name WHERE imgfile = '$photo'");
	}
	
}

/* if the failsafe buttons are turned in Options:Photopress, let's insert them */
if ($pp_failsafe_buttons == '1') {
	function pp_failsafe_buttons() {
		echo '
			<input type="button" value="Upload" onclick="return pp_upload_popup()" /> <input type="button" value="Browse" onclick="return pp_browse_popup()" />';
	}
	add_action('simple_edit_form', 'pp_failsafe_buttons');
	add_action('edit_form_advanced', 'pp_failsafe_buttons');
}

/* install a table in the db for PP image data */
function pp_table_install() {
	global $table_prefix, $wpdb, $user_level;
	$pp_table_version = 1;
//	$pp_installed_table_version = get_settings('pp_table_version');
	$table_name = $table_prefix . "photopress";
	get_currentuserinfo();
	if ($user_level < 8) { return; }
	$sql = "CREATE TABLE ".$table_name." (
		id mediumint(9) NOT NULL AUTO_INCREMENT,
		imgfile varchar(55) NOT NULL,
		imgname varchar(55) NULL,
		imgdesc text NULL,
		imgcat varchar(55) NULL,
		UNIQUE KEY id (id)
	);";
	require_once(ABSPATH . 'wp-admin/upgrade-functions.php');
	dbDelta($sql);

/* import image info stored in the WP Options with previous version of PP */
	if (get_option('pp_album_cats')) {
		$images = array();
		$images = pp_folder_contents();
		$cat_array = array();
		$cat_array = get_option('pp_album_cats');
		foreach($images as $img) {
			$img_key = substr_replace($img, '_', -4, 1);
			if (!empty($cat_array[$img_key])) {
				$category = $cat_array[$img_key];
			} else {
				$category = 'Default';
			}
			$name = strtr(substr($img, 0, -4), "_", " ");
			$import_array = array($img, $name, $name, $category);
			pp_table_update($import_array);
		}
	}

}

/* run the table installer when the plugin is activated */
if (isset($_GET['activate']) && $_GET['activate'] == 'true') {
	add_action('init', 'pp_table_install');
}

?>
